@@ -10,7 +10,7 @@ from typing import Tuple
 
 import instance_seg.logging_util as logging_util
 
-warnings.filterwarnings( 'ignore' )
+warnings.filterwarnings('ignore')
 
 
 
@@ -56,7 +56,7 @@ class ImageAugmentation():
             logger.warning(f'problem: Image rotation    desc : {e}')
         
         
-    def image_affine(self,image:np.array,polygons:Polygon,H,W,scale_range:range=(0.5,1.2)) -> Tuple[Polygon,np.array]:
+    def image_affine(self,image:np.array,polygons:Polygon,H,W,scale_range:range=(0.5,1.5)) -> Tuple[Polygon,np.array]:
         try:
             aug = iaa.Sequential([iaa.Affine(scale=scale_range,fit_output=True,),
                                 iaa.Resize({"height": H, "width": W})])
@@ -66,7 +66,7 @@ class ImageAugmentation():
         except Exception as e:
             logger.warning(f'problem: Image affine    desc : {e}')
 
-    def image_perspective_transform(self,image:np.array,polygons:Polygon,H,W,scale_range:range=(0.01,0.2)) -> Tuple[Polygon,np.array]:
+    def image_perspective_transform(self,image:np.array,polygons:Polygon,H,W,scale_range:range=(0.03,0.09)) -> Tuple[Polygon,np.array]:
         try:
             aug = iaa.Sequential([iaa.PerspectiveTransform(scale=scale_range,fit_output=True),
                                 iaa.Resize({"height": H, "width": W})])
@@ -82,11 +82,11 @@ class ImageAugmentation():
         try:
             choice = random.choice([0,1])
             if choice == 0:
-                aug = iaa.Sequential([iaa.AdditiveGaussianNoise(scale=(7,0.1*220), per_channel=False),
+                aug = iaa.Sequential([iaa.SaltAndPepper(p=(0,0.03)),
                                 iaa.Resize({"height": H, "width": W})])
             else:
                 # aug = iaa.AdditiveLaplaceNoise(scale=(5,0.1*200), per_channel=True)
-                aug = iaa.Sequential([iaa.AdditiveLaplaceNoise(scale=(7,0.1*220), per_channel=True),
+                aug = iaa.Sequential([iaa.SaltAndPepper(p=(0,0.03),per_channel=True),
                                 iaa.Resize({"height": H, "width": W})])
             new_points_polygons, aug_affine_image = aug(polygons=polygons,image=image)
             new_points_polygons = new_points_polygons.polygons
@@ -218,13 +218,7 @@ class ImageAugmentation():
             yield new_points_polygons , aug_affine_image
         except Exception as e:
             logger.warning(f'problem: Image rotate90   desc : {e}')
-
-    # def image_resize(self,image,polygons,height=640,):
-    #     aug = iaa.Resize({"height": height, "width": "keep-aspect-ratio"})
-    #     new_points_polygons, aug_affine_image = aug(polygons=polygons,image=image)
-    #     new_points_polygons = new_points_polygons.polygons
-    #     return new_points_polygons , aug_affine_image
-
+            
 
     # beta mode
     def image_weatherChange(self,image:np.array,polygons:Polygon,H,W,rain_speed:range=(0.1,0.3)) -> Tuple[Polygon,np.array]:
@@ -265,7 +259,7 @@ class ImageAugmentation():
         try:
             aug = iaa.Sequential([iaa.GaussianBlur(sigma=(0.8, 2.5)),
                                 iaa.Resize({"height": H, "width": W}),
-                                iaa.AdditiveGaussianNoise(scale=(2,0.1*200), per_channel=False)])
+                                iaa.SaltAndPepper(p=(0,0.03))])
             new_points_polygons, aug_affine_image = aug(polygons=polygons,image=image)
             new_points_polygons = new_points_polygons.polygons
             yield new_points_polygons , aug_affine_image
@@ -293,7 +287,7 @@ class ImageAugmentation():
             aug = iaa.Sequential([iaa.Rotate((-10,10),fit_output=True),
                                 iaa.WithBrightnessChannels(iaa.Add((-30,30))),
                                 iaa.RemoveSaturation(choices),
-                                iaa.PerspectiveTransform(scale=(0.01,0.1),fit_output=True),
+                                iaa.PerspectiveTransform(scale=(0.03,0.09),fit_output=True),
                                 iaa.Resize({"height": H, "width": W})])
             
                                 
@@ -340,7 +334,7 @@ class ImageAugmentation():
                 
                 aug = iaa.Sequential([iaa.Rotate(rotate=choice,fit_output=True),
                                 iaa.WithBrightnessChannels(iaa.Add((-20,20))),
-                                iaa.AdditiveGaussianNoise(scale=(2,0.1*150), per_channel=False),
+                                iaa.SaltAndPepper(p=(0,0.03)),
                                 iaa.Resize({"height": H, "width": W})])
             
                                 
