@@ -32,7 +32,7 @@ Code logic starts from here.
 '''
 
 class PolygonAugmentation():
-    def __init__(self,aug_save_folder_name:os.path='polygon_augmentation',yolo=True) -> None:
+    def __init__(self,aug_save_folder_name:os.path='polygon_augmentation',yolo:bool=True) -> None:
         self.aug_save_folder_name = aug_save_folder_name
         self.augment = ImageAugmentation()
         self.store_dict:dict = dict()
